@@ -6,7 +6,7 @@ from collections import namedtuple
 
 from psycopg.sql import SQL
 
-from .main import special_command, RAW_QUERY
+from .main import special_command
 
 TableInfo = namedtuple(
     "TableInfo",
@@ -17,8 +17,8 @@ TableInfo = namedtuple(
         "hasrules",
         "hastriggers",
         "hasoids",
-        "tablespace",
         "reloptions",
+        "tablespace",
         "reloftype",
         "relpersistence",
         "relispartition",
@@ -32,12 +32,12 @@ log = logging.getLogger(__name__)
 def list_databases(cur, pattern, verbose):
     params = {}
     query = SQL(
-        """SELECT d.datname as "Name",
-        pg_catalog.pg_get_userbyid(d.datdba) as "Owner",
-        pg_catalog.pg_encoding_to_char(d.encoding) as "Encoding",
-        d.datcollate as "Collate",
-        d.datctype as "Ctype",
-        pg_catalog.array_to_string(d.datacl, E'\n') AS "Access privileges"
+        """SELECT d.datname as name,
+        pg_catalog.pg_get_userbyid(d.datdba) as owner,
+        pg_catalog.pg_encoding_to_char(d.encoding) as encoding,
+        d.datcollate as collate,
+        d.datctype as ctype,
+        pg_catalog.array_to_string(d.datacl, E'\n') AS access_privileges
         {verbose_fields}
         FROM pg_catalog.pg_database d
         {verbose_tables}
@@ -46,17 +46,15 @@ def list_databases(cur, pattern, verbose):
     )
     if verbose:
         params["verbose_fields"] = SQL(
-            ''',
+            """,
             CASE WHEN pg_catalog.has_database_privilege(d.datname, 'CONNECT')
                     THEN pg_catalog.pg_size_pretty(pg_catalog.pg_database_size(d.datname))
                     ELSE 'No Access'
-            END as "Size",
+            END as size,
             t.spcname as "Tablespace",
-            pg_catalog.shobj_description(d.oid, 'pg_database') as "Description"'''
-        )
-        params["verbose_tables"] = SQL(
-            """JOIN pg_catalog.pg_tablespace t on d.dattablespace = t.oid"""
+            pg_catalog.shobj_description(d.oid, 'pg_database') as description"""
         )
+        params["verbose_tables"] = SQL("""JOIN pg_catalog.pg_tablespace t on d.dattablespace = t.oid""")
     else:
         params["verbose_fields"] = SQL("")
         params["verbose_tables"] = SQL("")
@@ -70,7 +68,7 @@ def list_databases(cur, pattern, verbose):
     log.debug(formatted_query.as_string(cur))
     cur.execute(formatted_query)
     if cur.description:
-        headers = [x.name for x in cur.description]
+        headers = [titleize(x.name) for x in cur.description]
         return [(None, cur, headers, cur.statusmessage)]
     else:
         return [(None, None, None, cur.statusmessage)]
@@ -104,9 +102,7 @@ def list_roles(cur, pattern, verbose):
             """
         )
         if verbose:
-            params["verbose"] = SQL(
-                """pg_catalog.shobj_description(r.oid, 'pg_authid') AS description, """
-            )
+            params["verbose"] = SQL("""pg_catalog.shobj_description(r.oid, 'pg_authid') AS description, """)
         else:
             params["verbose"] = SQL("")
     else:
@@ -139,25 +135,26 @@ def list_roles(cur, pattern, verbose):
         return [(None, cur, headers, cur.statusmessage)]
 
 
-@special_command("\\dp", "\\dp [pattern]", "List roles.", aliases=("\\z",))
+@special_command("\\dp", "\\dp [pattern]", "List privileges.", aliases=("\\z",))
 def list_privileges(cur, pattern, verbose):
     """Returns (title, rows, headers, status)"""
     sql = SQL(
         """
-        SELECT n.nspname as "Schema",
-          c.relname as "Name",
+        SELECT n.nspname as schema,
+          c.relname as name,
           CASE c.relkind WHEN 'r' THEN 'table'
                          WHEN 'v' THEN 'view'
                          WHEN 'm' THEN 'materialized view'
                          WHEN 'S' THEN 'sequence'
                          WHEN 'f' THEN 'foreign table'
-                         WHEN 'p' THEN 'partitioned table' END as "Type",
-          pg_catalog.array_to_string(c.relacl, E'\n') AS "Access privileges",
+                         WHEN 'p' THEN 'partitioned table' END as type,
+          pg_catalog.array_to_string(c.relacl, E'\n') AS access_privileges,
+
           pg_catalog.array_to_string(ARRAY(
             SELECT attname || E':\n  ' || pg_catalog.array_to_string(attacl, E'\n  ')
             FROM pg_catalog.pg_attribute a
             WHERE attrelid = c.oid AND NOT attisdropped AND attacl IS NOT NULL
-          ), E'\n') AS "Column privileges",
+          ), E'\n') AS column_privileges,
           pg_catalog.array_to_string(ARRAY(
             SELECT polname
             || CASE WHEN NOT polpermissive THEN
@@ -186,7 +183,7 @@ def list_privileges(cur, pattern, verbose):
                END
             FROM pg_catalog.pg_policy pol
             WHERE polrelid = c.oid), E'\n')
-            AS "Policies"
+            AS policies
         FROM pg_catalog.pg_class c
              LEFT JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace
     """
@@ -195,13 +192,9 @@ def list_privileges(cur, pattern, verbose):
     if pattern:
         schema, table = sql_name_pattern(pattern)
         if table:
-            pattern = SQL(
-                " AND c.relname OPERATOR(pg_catalog.~) {} COLLATE pg_catalog.default "
-            ).format(table)
+            pattern = SQL(" AND c.relname OPERATOR(pg_catalog.~) {} COLLATE pg_catalog.default ").format(table)
         if schema:
-            pattern += SQL(
-                " AND n.nspname OPERATOR(pg_catalog.~) {} COLLATE pg_catalog.default "
-            ).format(schema)
+            pattern += SQL(" AND n.nspname OPERATOR(pg_catalog.~) {} COLLATE pg_catalog.default ").format(schema)
     else:
         pattern = SQL(" AND pg_catalog.pg_table_is_visible(c.oid) ")
 
@@ -218,7 +211,7 @@ def list_privileges(cur, pattern, verbose):
     log.debug(sql.as_string(cur))
     cur.execute(sql)
     if cur.description:
-        headers = [x.name for x in cur.description]
+        headers = [titleize(x.name) for x in cur.description]
         return [(None, cur, headers, cur.statusmessage)]
 
 
@@ -227,14 +220,14 @@ def list_default_privileges(cur, pattern, verbose):
     """Returns (title, rows, headers, status)"""
     sql = SQL(
         """
-    SELECT pg_catalog.pg_get_userbyid(d.defaclrole) AS "Owner",
-    n.nspname AS "Schema",
+    SELECT pg_catalog.pg_get_userbyid(d.defaclrole) AS owner,
+    n.nspname AS schema,
     CASE d.defaclobjtype WHEN 'r' THEN 'table'
                          WHEN 'S' THEN 'sequence'
                          WHEN 'f' THEN 'function'
                          WHEN 'T' THEN 'type'
-                         WHEN 'n' THEN 'schema' END AS "Type",
-    pg_catalog.array_to_string(d.defaclacl, E'\n') AS "Access privileges"
+                         WHEN 'n' THEN 'schema' END as type,
+    pg_catalog.array_to_string(d.defaclacl, E'\n') AS access_privileges
     FROM pg_catalog.pg_default_acl d
         LEFT JOIN pg_catalog.pg_namespace n ON n.oid = d.defaclnamespace
         {where_clause}
@@ -256,7 +249,7 @@ def list_default_privileges(cur, pattern, verbose):
     log.debug(sql.format(**params).as_string(cur))
     cur.execute(sql.format(**params))
     if cur.description:
-        headers = [x.name for x in cur.description]
+        headers = [titleize(x.name) for x in cur.description]
         return [(None, cur, headers, cur.statusmessage)]
 
 
@@ -267,14 +260,12 @@ def list_tablespaces(cur, pattern, **_):
     """
 
     params = {}
-    cur.execute(
-        "SELECT EXISTS(SELECT * FROM pg_proc WHERE proname = 'pg_tablespace_location')"
-    )
+    cur.execute("SELECT EXISTS(SELECT * FROM pg_proc WHERE proname = 'pg_tablespace_location')")
     (is_location,) = cur.fetchone()
 
     sql = SQL(
-        """SELECT n.spcname AS "Name", pg_catalog.pg_get_userbyid(n.spcowner) AS "Owner",
-                {location} AS "Location" FROM pg_catalog.pg_tablespace n
+        """SELECT n.spcname AS name, pg_catalog.pg_get_userbyid(n.spcowner) AS owner,
+                {location} AS location FROM pg_catalog.pg_tablespace n
                 {pattern}
                 ORDER BY 1
               """
@@ -295,7 +286,7 @@ def list_tablespaces(cur, pattern, **_):
     log.debug(formatted_query.as_string(cur))
     cur.execute(formatted_query)
 
-    headers = [x.name for x in cur.description] if cur.description else None
+    headers = [titleize(x.name) for x in cur.description] if cur.description else None
     return [(None, cur, headers, cur.statusmessage)]
 
 
@@ -307,7 +298,7 @@ def list_schemas(cur, pattern, verbose):
 
     params = {}
     sql = SQL(
-        """SELECT n.nspname AS "Name", pg_catalog.pg_get_userbyid(n.nspowner) AS "Owner"
+        """SELECT n.nspname AS name, pg_catalog.pg_get_userbyid(n.nspowner) AS owner
                 {verbose}
               FROM pg_catalog.pg_namespace n WHERE n.nspname
                 {pattern}
@@ -317,7 +308,7 @@ def list_schemas(cur, pattern, verbose):
 
     if verbose:
         params["verbose"] = SQL(
-            ''', pg_catalog.array_to_string(n.nspacl, E'\\n') AS "Access privileges", pg_catalog.obj_description(n.oid, 'pg_namespace') AS "Description"'''
+            """, pg_catalog.array_to_string(n.nspacl, E'\\n') AS access_privileges, pg_catalog.obj_description(n.oid, 'pg_namespace') AS description"""
         )
     else:
         params["verbose"] = SQL("")
@@ -332,7 +323,7 @@ def list_schemas(cur, pattern, verbose):
     log.debug(formatted_query.as_string(cur))
     cur.execute(formatted_query)
     if cur.description:
-        headers = [x.name for x in cur.description]
+        headers = [titleize(x.name) for x in cur.description]
         return [(None, cur, headers, cur.statusmessage)]
 
 
@@ -342,7 +333,8 @@ def list_extensions(cur, pattern, verbose):
     def _find_extensions(cur, pattern):
         sql = SQL(
             """
-            SELECT e.extname, e.oid FROM pg_catalog.pg_extension e
+            SELECT e.extname, e.oid
+            FROM pg_catalog.pg_extension e
             {pattern}
             ORDER BY 1, 2;
         """
@@ -364,7 +356,7 @@ def list_extensions(cur, pattern, verbose):
         sql = SQL(
             """
             SELECT  pg_catalog.pg_describe_object(classid, objid, 0)
-                    AS "Object Description"
+                    AS object_description
             FROM    pg_catalog.pg_depend
             WHERE   refclassid = 'pg_catalog.pg_extension'::pg_catalog.regclass
                     AND refobjid = {}
@@ -374,7 +366,7 @@ def list_extensions(cur, pattern, verbose):
         log.debug(sql.as_string(cur))
         cur.execute(sql)
 
-        headers = [x.name for x in cur.description]
+        headers = [titleize(x.name) for x in cur.description]
         return cur, headers, cur.statusmessage
 
     if cur.connection.info.server_version < 90100:
@@ -397,10 +389,10 @@ def list_extensions(cur, pattern, verbose):
 
     sql = SQL(
         """
-      SELECT e.extname AS "Name",
-             e.extversion AS "Version",
-             n.nspname AS "Schema",
-             c.description AS "Description"
+      SELECT e.extname AS name,
+             e.extversion AS version,
+             n.nspname AS schema,
+             c.description AS description
       FROM pg_catalog.pg_extension e
            LEFT JOIN pg_catalog.pg_namespace n
              ON n.oid = e.extnamespace
@@ -423,7 +415,7 @@ def list_extensions(cur, pattern, verbose):
     log.debug(formatted_query.as_string(cur))
     cur.execute(formatted_query)
     if cur.description:
-        headers = [x.name for x in cur.description]
+        headers = [titleize(x.name) for x in cur.description]
         yield None, cur, headers, cur.statusmessage
 
 
@@ -443,23 +435,23 @@ def list_objects(cur, pattern, verbose, relkinds):
     if verbose:
         params["verbose_columns"] = SQL(
             """
-            ,pg_catalog.pg_size_pretty(pg_catalog.pg_table_size(c.oid)) as "Size",
-            pg_catalog.obj_description(c.oid, 'pg_class') as "Description" """
+            ,pg_catalog.pg_size_pretty(pg_catalog.pg_table_size(c.oid)) as size,
+            pg_catalog.obj_description(c.oid, 'pg_class') as description """
         )
     else:
         params["verbose_columns"] = SQL("")
 
     sql = SQL(
-        """SELECT n.nspname as "Schema",
-                    c.relname as "Name",
+        """SELECT n.nspname as schema,
+                    c.relname as name,
                     CASE c.relkind
                       WHEN 'r' THEN 'table' WHEN 'v' THEN 'view'
                       WHEN 'p' THEN 'partitioned table'
                       WHEN 'm' THEN 'materialized view' WHEN 'i' THEN 'index'
                       WHEN 'S' THEN 'sequence' WHEN 's' THEN 'special'
                       WHEN 'f' THEN 'foreign table' END
-                    as "Type",
-                    pg_catalog.pg_get_userbyid(c.relowner) as "Owner"
+                    as type,
+                    pg_catalog.pg_get_userbyid(c.relowner) as owner
                     {verbose_columns}
             FROM    pg_catalog.pg_class c
                     LEFT JOIN pg_catalog.pg_namespace n
@@ -492,7 +484,7 @@ def list_objects(cur, pattern, verbose, relkinds):
     cur.execute(formatted_query)
 
     if cur.description:
-        headers = [x.name for x in cur.description]
+        headers = [titleize(x.name) for x in cur.description]
         return [(None, cur, headers, cur.statusmessage)]
 
 
@@ -530,10 +522,10 @@ def list_functions(cur, pattern, verbose):
                  WHEN p.provolatile = 's' THEN 'stable'
                  WHEN p.provolatile = 'v' THEN 'volatile'
             END as "Volatility",
-            pg_catalog.pg_get_userbyid(p.proowner) as "Owner",
+            pg_catalog.pg_get_userbyid(p.proowner) as owner,
           l.lanname as "Language",
           p.prosrc as "Source code",
-          pg_catalog.obj_description(p.oid, 'pg_proc') as "Description" """
+          pg_catalog.obj_description(p.oid, 'pg_proc') as description """
 
         verbose_table = """ LEFT JOIN pg_catalog.pg_language l
                                 ON l.oid = p.prolang"""
@@ -543,8 +535,8 @@ def list_functions(cur, pattern, verbose):
     if cur.connection.info.server_version >= 110000:
         sql = (
             """
-            SELECT  n.nspname as "Schema",
-                    p.proname as "Name",
+            SELECT  n.nspname as schema,
+                    p.proname as name,
                     pg_catalog.pg_get_function_result(p.oid)
                       as "Result data type",
                     pg_catalog.pg_get_function_arguments(p.oid)
@@ -555,7 +547,7 @@ def list_functions(cur, pattern, verbose):
                         WHEN p.prorettype = 'pg_catalog.trigger'::pg_catalog.regtype
                             THEN 'trigger'
                         ELSE 'normal'
-                    END as "Type" """
+                    END as type """
             + verbose_columns
             + """
             FROM    pg_catalog.pg_proc p
@@ -568,8 +560,8 @@ def list_functions(cur, pattern, verbose):
     elif cur.connection.info.server_version > 90000:
         sql = (
             """
-            SELECT  n.nspname as "Schema",
-                    p.proname as "Name",
+            SELECT  n.nspname as schema,
+                    p.proname as name,
                     pg_catalog.pg_get_function_result(p.oid)
                       as "Result data type",
                     pg_catalog.pg_get_function_arguments(p.oid)
@@ -580,7 +572,7 @@ def list_functions(cur, pattern, verbose):
                         WHEN p.prorettype = 'pg_catalog.trigger'::pg_catalog.regtype
                             THEN 'trigger'
                         ELSE 'normal'
-                    END as "Type" """
+                    END as type """
             + verbose_columns
             + """
             FROM    pg_catalog.pg_proc p
@@ -593,15 +585,15 @@ def list_functions(cur, pattern, verbose):
     else:
         sql = (
             """
-            SELECT  n.nspname as "Schema",
-                    p.proname as "Name",
+            SELECT  n.nspname as schema,
+                    p.proname as name,
                     pg_catalog.format_type(p.prorettype, NULL) as "Result data type",
                     pg_catalog.oidvectortypes(p.proargtypes) as "Argument data types",
                      CASE
                         WHEN p.proisagg THEN 'agg'
                         WHEN p.prorettype = 'pg_catalog.trigger'::pg_catalog.regtype THEN 'trigger'
                         ELSE 'normal'
-                    END as "Type" """
+                    END as type """
             + verbose_columns
             + """
             FROM    pg_catalog.pg_proc p
@@ -635,38 +627,38 @@ def list_functions(cur, pattern, verbose):
     cur.execute(sql, params)
 
     if cur.description:
-        headers = [x.name for x in cur.description]
+        headers = [titleize(x.name) for x in cur.description]
         return [(None, cur, headers, cur.statusmessage)]
 
 
 @special_command("\\dT", "\\dT[S+] [pattern]", "List data types")
 def list_datatypes(cur, pattern, verbose):
-    sql = """SELECT n.nspname as "Schema",
-                    pg_catalog.format_type(t.oid, NULL) AS "Name", """
+    sql = """SELECT n.nspname as schema,
+                    pg_catalog.format_type(t.oid, NULL) AS name, """
 
     if verbose:
-        sql += r''' t.typname AS "Internal name",
+        sql += r""" t.typname AS internal_name,
                     CASE
                         WHEN t.typrelid != 0
                             THEN CAST('tuple' AS pg_catalog.text)
                         WHEN t.typlen < 0
                             THEN CAST('var' AS pg_catalog.text)
                         ELSE CAST(t.typlen AS pg_catalog.text)
-                    END AS "Size",
+                    END AS size,
                     pg_catalog.array_to_string(
                         ARRAY(
                               SELECT e.enumlabel
                               FROM pg_catalog.pg_enum e
                               WHERE e.enumtypid = t.oid
                               ORDER BY e.enumsortorder
-                          ), E'\n') AS "Elements",
+                          ), E'\n') AS elements,
                     pg_catalog.array_to_string(t.typacl, E'\n')
-                        AS "Access privileges",
+                        AS access_privileges,
                     pg_catalog.obj_description(t.oid, 'pg_type')
-                        AS "Description"'''
+                        AS description"""
     else:
         sql += """  pg_catalog.obj_description(t.oid, 'pg_type')
-                        as "Description" """
+                        as description """
 
     if cur.connection.info.server_version > 90000:
         sql += """  FROM    pg_catalog.pg_type t
@@ -712,16 +704,16 @@ def list_datatypes(cur, pattern, verbose):
     log.debug("%s, %s", sql, params)
     cur.execute(sql, params)
     if cur.description:
-        headers = [x.name for x in cur.description]
+        headers = [titleize(x.name) for x in cur.description]
         return [(None, cur, headers, cur.statusmessage)]
 
 
 @special_command("\\dD", "\\dD[+] [pattern]", "List or describe domains.")
 def list_domains(cur, pattern, verbose):
     if verbose:
-        extra_cols = r''',
-               pg_catalog.array_to_string(t.typacl, E'\n') AS "Access privileges",
-               d.description as "Description"'''
+        extra_cols = r""",
+               pg_catalog.array_to_string(t.typacl, E'\n') AS access_privileges,
+               d.description as description"""
         extra_joins = """
            LEFT JOIN pg_catalog.pg_description d ON d.classoid = t.tableoid
                                                 AND d.objoid = t.oid AND d.objsubid = 0"""
@@ -729,9 +721,9 @@ def list_domains(cur, pattern, verbose):
         extra_cols = extra_joins = ""
 
     sql = f"""\
-        SELECT n.nspname AS "Schema",
-               t.typname AS "Name",
-               pg_catalog.format_type(t.typbasetype, t.typtypmod) AS "Type",
+        SELECT n.nspname AS schema,
+               t.typname AS name,
+               pg_catalog.format_type(t.typbasetype, t.typtypmod) as type,
                pg_catalog.ltrim((COALESCE((SELECT (' collate ' || c.collname)
                                            FROM pg_catalog.pg_collation AS c,
                                                 pg_catalog.pg_type AS bt
@@ -746,11 +738,11 @@ def list_domains(cur, pattern, verbose):
                                              WHEN t.typdefault IS NOT NULL
                                                THEN(' default ' || t.typdefault)
                                              ELSE ''
-                                           END) AS "Modifier",
+                                           END) AS modifier,
                pg_catalog.array_to_string(ARRAY(
                  SELECT pg_catalog.pg_get_constraintdef(r.oid, TRUE)
                  FROM pg_catalog.pg_constraint AS r
-                 WHERE t.oid = r.contypid), ' ') AS "Check"{extra_cols}
+                 WHERE t.oid = r.contypid), ' ') AS check {extra_cols}
         FROM pg_catalog.pg_type AS t
            LEFT JOIN pg_catalog.pg_namespace AS n ON n.oid = t.typnamespace{extra_joins}
         WHERE t.typtype = 'd' """
@@ -774,7 +766,7 @@ def list_domains(cur, pattern, verbose):
     log.debug("%s, %s", sql, params)
     cur.execute(sql, params)
     if cur.description:
-        headers = [x.name for x in cur.description]
+        headers = [titleize(x.name) for x in cur.description]
         return [(None, cur, headers, cur.statusmessage)]
 
 
@@ -811,13 +803,13 @@ def list_text_search_configurations(cur, pattern, verbose):
             SELECT
               (SELECT t.alias
                FROM pg_catalog.ts_token_type(c.cfgparser) AS t
-               WHERE t.tokid = m.maptokentype ) AS "Token",
+               WHERE t.tokid = m.maptokentype ) AS token,
                    pg_catalog.btrim(ARRAY
                                       (SELECT mm.mapdict::pg_catalog.regdictionary
                                        FROM pg_catalog.pg_ts_config_map AS mm
                                        WHERE mm.mapcfg = m.mapcfg
                                          AND mm.maptokentype = m.maptokentype
-                                       ORDER BY mapcfg, maptokentype, mapseqno) :: pg_catalog.text, '{}') AS "Dictionaries"
+                                       ORDER BY mapcfg, maptokentype, mapseqno) :: pg_catalog.text, '{}') AS dictionaries
             FROM pg_catalog.pg_ts_config AS c,
                  pg_catalog.pg_ts_config_map AS m
             WHERE c.oid = %(oid)s
@@ -831,7 +823,7 @@ def list_text_search_configurations(cur, pattern, verbose):
         log.debug("%s, %s", sql, params)
         cur.execute(sql, params)
 
-        headers = [x.name for x in cur.description]
+        headers = [titleize(x.name) for x in cur.description]
         return cur, headers, cur.statusmessage
 
     if cur.connection.info.server_version < 80300:
@@ -851,15 +843,18 @@ def list_text_search_configurations(cur, pattern, verbose):
                 cur, headers, status = _fetch_oid_details(cur, oid)
                 yield title, cur, headers, status
         else:
-            yield None, None, None, 'Did not find any results for pattern "{}".'.format(
-                pattern
+            yield (
+                None,
+                None,
+                None,
+                'Did not find any results for pattern "{}".'.format(pattern),
             )
         return
 
     sql = """
-        SELECT n.nspname AS "Schema",
-               c.cfgname AS "Name",
-               pg_catalog.obj_description(c.oid, 'pg_ts_config') AS "Description"
+        SELECT n.nspname AS schema,
+               c.cfgname AS name,
+               pg_catalog.obj_description(c.oid, 'pg_ts_config') AS description
         FROM pg_catalog.pg_ts_config c
         LEFT JOIN pg_catalog.pg_namespace n ON n.oid = c.cfgnamespace
         """
@@ -874,16 +869,12 @@ def list_text_search_configurations(cur, pattern, verbose):
     log.debug("%s, %s", sql, params)
     cur.execute(sql, params)
     if cur.description:
-        headers = [x.name for x in cur.description]
+        headers = [titleize(x.name) for x in cur.description]
         yield None, cur, headers, cur.statusmessage
 
 
-@special_command(
-    "describe", "DESCRIBE [pattern]", "", hidden=True, case_sensitive=False
-)
-@special_command(
-    "\\d", "\\d[+] [pattern]", "List or describe tables, views and sequences."
-)
+@special_command("describe", "DESCRIBE [pattern]", "", hidden=True, case_sensitive=False)
+@special_command("\\d", "\\d[+] [pattern]", "List or describe tables, views and sequences.")
 def describe_table_details(cur, pattern, verbose):
     """
     Returns (title, rows, headers, status)
@@ -980,7 +971,7 @@ def describe_one_table_details(cur, schema_name, relation_name, oid, verbose):
                     c.relhasoids,
                     {suffix},
                     c.reltablespace,
-                    0 AS reloftype,
+                    '' AS reloftype,
                     'p' AS relpersistence,
                     false as relispartition
                  FROM pg_catalog.pg_class c
@@ -996,7 +987,7 @@ def describe_one_table_details(cur, schema_name, relation_name, oid, verbose):
                     c.relhasoids,
                     {suffix},
                     c.reltablespace,
-                    0 AS reloftype,
+                    '' AS reloftype,
                     'p' AS relpersistence,
                     false as relispartition
                  FROM pg_catalog.pg_class c
@@ -1064,8 +1055,8 @@ def describe_one_table_details(cur, schema_name, relation_name, oid, verbose):
     if tableinfo.relkind == "i" or tableinfo.relkind == "I":
         if cur.connection.info.server_version >= 110000:
             sql += (
-                f",\n CASE WHEN a.attnum <= (SELECT i.indnkeyatts FROM pg_catalog.pg_index i "
-                "WHERE i.indexrelid = '{oid}') THEN 'yes' ELSE 'no' END AS is_key"
+                ",\n CASE WHEN a.attnum <= (SELECT i.indnkeyatts FROM pg_catalog.pg_index i "
+                f"WHERE i.indexrelid = '{oid}') THEN 'yes' ELSE 'no' END AS is_key"
             )
             att_cols["indexkey"] = cols
             cols += 1
@@ -1095,10 +1086,7 @@ def describe_one_table_details(cur, schema_name, relation_name, oid, verbose):
             or tableinfo.relkind == "f"
             or tableinfo.relkind == "p"
         ):
-            sql += (
-                ",\n  CASE WHEN a.attstattarget=-1 THEN "
-                "NULL ELSE a.attstattarget END AS attstattarget"
-            )
+            sql += ",\n  CASE WHEN a.attstattarget=-1 THEN NULL ELSE a.attstattarget END AS attstattarget"
             att_cols["attstattarget"] = cols
             cols += 1
         if (
@@ -1146,11 +1134,7 @@ def describe_one_table_details(cur, schema_name, relation_name, oid, verbose):
 
     if verbose:
         headers.append("Storage")
-        if (
-            tableinfo.relkind == "r"
-            or tableinfo.relkind == "m"
-            or tableinfo.relkind == "f"
-        ):
+        if tableinfo.relkind == "r" or tableinfo.relkind == "m" or tableinfo.relkind == "f":
             headers.append("Stats target")
         #  Column comments, if the relkind supports this feature. */
         if (
@@ -1220,11 +1204,7 @@ def describe_one_table_details(cur, schema_name, relation_name, oid, verbose):
             else:
                 cell.append("???")
 
-            if (
-                tableinfo.relkind == "r"
-                or tableinfo.relkind == "m"
-                or tableinfo.relkind == "f"
-            ):
+            if tableinfo.relkind == "r" or tableinfo.relkind == "m" or tableinfo.relkind == "f":
                 cell.append(row[att_cols["attstattarget"]])
 
             #  /* Column comments, if the relkind supports this feature. */
@@ -1370,12 +1350,7 @@ def describe_one_table_details(cur, schema_name, relation_name, oid, verbose):
         # * don't print anything.
         # */
 
-    elif (
-        tableinfo.relkind == "r"
-        or tableinfo.relkind == "p"
-        or tableinfo.relkind == "m"
-        or tableinfo.relkind == "f"
-    ):
+    elif tableinfo.relkind == "r" or tableinfo.relkind == "p" or tableinfo.relkind == "m" or tableinfo.relkind == "f":
         # /* Footer information about a table */
 
         if tableinfo.hasindex:
@@ -1437,7 +1412,7 @@ def describe_one_table_details(cur, schema_name, relation_name, oid, verbose):
             if cur.rowcount > 0:
                 status.append("Indexes:\n")
             for row in cur:
-                # /* untranslated index name */
+                # /* untranslated indextname */
                 status.append(f'''    "{row[0]}"''')
 
                 # /* If exclusion constraint, print the constraintdef */
@@ -1530,9 +1505,7 @@ def describe_one_table_details(cur, schema_name, relation_name, oid, verbose):
             if cur.rowcount > 0:
                 status.append("Referenced by:\n")
             for row in cur:
-                status.append(
-                    f"""    TABLE "{row[0]}" CONSTRAINT "{row[1]}" {row[2]}\n"""
-                )
+                status.append(f"""    TABLE "{row[0]}" CONSTRAINT "{row[1]}" {row[2]}\n""")
 
         # /* print rules */
         if tableinfo.hasrules and tableinfo.relkind != "m":
@@ -1630,10 +1603,7 @@ def describe_one_table_details(cur, schema_name, relation_name, oid, verbose):
                         else:
                             status.append(f"            {row[0]}\n")
                 else:
-                    status.append(
-                        "Number of partitions %i: (Use \\d+ to list them.)\n"
-                        % cur.rowcount
-                    )
+                    status.append("Number of partitions %i: (Use \\d+ to list them.)\n" % cur.rowcount)
 
     if view_def:
         # /* Footer information about a view */
@@ -1696,10 +1666,10 @@ def describe_one_table_details(cur, schema_name, relation_name, oid, verbose):
                     # */
                     tgenabled = row[2]
                     if category == 0:
-                        if tgenabled == "O" or tgenabled == True:
+                        if tgenabled == "O" or tgenabled is True:
                             list_trigger = True
                     elif category == 1:
-                        if tgenabled == "D" or tgenabled == False:
+                        if tgenabled == "D" or tgenabled is False:
                             list_trigger = True
                     elif category == 2:
                         if tgenabled == "A":
@@ -1707,7 +1677,7 @@ def describe_one_table_details(cur, schema_name, relation_name, oid, verbose):
                     elif category == 3:
                         if tgenabled == "R":
                             list_trigger = True
-                    if list_trigger == False:
+                    if list_trigger is False:
                         continue
 
                     # /* Print the category heading once */
@@ -1804,10 +1774,7 @@ def describe_one_table_details(cur, schema_name, relation_name, oid, verbose):
         if not verbose:
             # /* print the number of child tables, if any */
             if cur.rowcount > 0:
-                status.append(
-                    "Number of child tables: %d (Use \\d+ to list"
-                    " them.)\n" % cur.rowcount
-                )
+                status.append("Number of child tables: %d (Use \\d+ to list them.)\n" % cur.rowcount)
         else:
             if cur.rowcount > 0:
                 status.append("Child tables")
@@ -1915,7 +1882,7 @@ def show_function_definition(cur, pattern, verbose):
     log.debug("%s, %s", sql, params)
     cur.execute(sql, params)
     if cur.description:
-        headers = [x.name for x in cur.description]
+        headers = [titleize(x.name) for x in cur.description]
         if verbose:
             (source,) = cur.fetchone()
             rows = _FakeCursor()
@@ -1946,10 +1913,10 @@ def list_foreign_tables(cur, pattern, verbose):
     params = {}
     query = SQL(
         """
-        SELECT n.nspname as "Schema",
-        c.relname as "Name",
-        CASE c.relkind WHEN 'r' THEN 'table' WHEN 'v' THEN 'view' WHEN 'm' THEN 'materialized view' WHEN 'i' THEN 'index' WHEN 'S' THEN 'sequence' WHEN 's' THEN 'special' WHEN 'f' THEN 'foreign table' WHEN 'p' THEN 'table' WHEN 'I' THEN 'index' END as "Type",
-        pg_catalog.pg_get_userbyid(c.relowner) as "Owner"
+        SELECT n.nspname as schema,
+        c.relname as name,
+        CASE c.relkind WHEN 'r' THEN 'table' WHEN 'v' THEN 'view' WHEN 'm' THEN 'materialized view' WHEN 'i' THEN 'index' WHEN 'S' THEN 'sequence' WHEN 's' THEN 'special' WHEN 'f' THEN 'foreign table' WHEN 'p' THEN 'table' WHEN 'I' THEN 'index' END as type,
+        pg_catalog.pg_get_userbyid(c.relowner) as owner
         {verbose_cols}
         FROM pg_catalog.pg_class c
             LEFT JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace
@@ -1966,17 +1933,15 @@ def list_foreign_tables(cur, pattern, verbose):
     if verbose:
         params["verbose_cols"] = SQL(
             """
-            , pg_catalog.pg_size_pretty(pg_catalog.pg_table_size(c.oid)) as "Size",
-            pg_catalog.obj_description(c.oid, 'pg_class') as "Description" """
+            , pg_catalog.pg_size_pretty(pg_catalog.pg_table_size(c.oid)) as size,
+            pg_catalog.obj_description(c.oid, 'pg_class') as description """
         )
     else:
         params["verbose_cols"] = SQL("")
 
     if pattern:
         _, tbl_name = sql_name_pattern(pattern)
-        params["filter"] = SQL(" AND c.relname OPERATOR(pg_catalog.~) {} ").format(
-            f"^({tbl_name})$"
-        )
+        params["filter"] = SQL(" AND c.relname OPERATOR(pg_catalog.~) {} ").format(f"^({tbl_name})$")
     else:
         params["filter"] = SQL("")
 
@@ -1984,7 +1949,11 @@ def list_foreign_tables(cur, pattern, verbose):
     log.debug(formatted_query.as_string(cur))
     cur.execute(formatted_query)
     if cur.description:
-        headers = [x.name for x in cur.description]
+        headers = [titleize(x.name) for x in cur.description]
         return [(None, cur, headers, cur.statusmessage)]
     else:
         return [(None, None, None, cur.statusmessage)]
+
+
+def titleize(column):
+    return column[0].capitalize() + " ".join(c for c in column[1:].split("_"))
